import express from 'express';
import bcrypt from 'bcrypt';
import multer from 'multer';
import path from 'path';
import { fileURLToPath } from 'url';
import { v4 as uuidv4 } from 'uuid'; // مكتبة لتوليد معرفات فريدة ${uuidv4()}${ext}
import db from './db.js'


const router = express.Router();


const __filename = fileURLToPath(import.meta.url);
const __dirname = path.dirname(__filename);


// إعداد التخزين للصور
const storage = multer.diskStorage({
  destination: (req, file, cb) => {
    cb(null, 'uploadsadmin/');
  },
  filename: (req, file, cb) => {
    const ext = path.extname(file.originalname);
    cb(null, `${Date.now()}-${uuidv4()}${ext}`);
  },
});
const upload = multer({ storage });


router.post('/add', upload.single('image'), async (req, res) => {
    const { username, email, password, role, phone, is_visible_a } = req.body;
    const image = req.file ? req.file.filename : null;
  
    try {
      // تشفير كلمة المرور باستخدام bcrypt
      const hashedPassword = await bcrypt.hash(password, 10); // الرقم 10 يشير إلى قوة التشفير
  
      const query = `
        INSERT INTO admins (username, email, password, role, phone, image, is_visible_a)
        VALUES (?, ?, ?, ?, ?, ?, ?)
      `;
  
      // إدخال البيانات مع كلمة المرور المشفرة
      await db.execute(query, [username, email, hashedPassword, role, phone, image, is_visible_a]);
      res.status(201).json({ message: 'User added successfully' });
    } catch (error) {
      res.status(500).json({ message: 'Error adding user' });
    }
  });
  
  
  export default router;
  