import express from 'express';
import db from './db.js';

const router = express.Router();

// استرجاع الإعلانات
router.get('/public-ads', async (req, res) => {
//  console.log(`[${new Date().toISOString()}] Fetching ads...`);
  try {
    const query = `
      SELECT 
        ads.*, 
        areas.area AS area, 
        cities.city AS city 
      FROM ads
      LEFT JOIN areas ON ads.areasid = areas.id
      LEFT JOIN cities ON ads.citiesid = cities.id
      WHERE dateend >= CURDATE()
    `;
    const [rows] = await db.query(query);
    res.json(rows);
  } catch (error) {
   // console.error(`[${new Date().toISOString()}] Error fetching ads:`, error.message);
    res.status(500).json({ message: 'حدث خطأ أثناء جلب الإعلانات.' });
  }
});


// جلب تفاصيل الإعلان بناءً على المعرف
router.get('/ads/:id', async (req, res) => {
  const { id } = req.params; // استخراج المعرف من الرابط
  try {
    // استعلام لجلب تفاصيل الإعلان بناءً على المعرف
    const query = `
      SELECT 
        ads.*, 
        areas.area AS area, 
        cities.city AS city 
      FROM ads
      LEFT JOIN areas ON ads.areasid = areas.id
      LEFT JOIN cities ON ads.citiesid = cities.id
      WHERE ads.id = ?
    `;
    const [rows] = await db.query(query, [id]);

    // التحقق إذا كان الإعلان موجودًا
    if (rows.length === 0) {
      return res.status(404).json({ message: 'الإعلان غير موجود.' });
    }

    // إرسال تفاصيل الإعلان
    res.json(rows[0]);
  } catch (error) {
    res.status(500).json({ message: 'حدث خطأ أثناء جلب تفاصيل الإعلان.' });
  }
});

// استرجاع الأقسام
router.get('/public-categories', async (req, res) => {
  try {
    const query = 'SELECT * FROM alaqsam';
    const [rows] = await db.query(query);
    res.json(rows);
  } catch (error) {
    res.status(500).json({ message: 'حدث خطأ أثناء جلب الأقسام.' });
  }
});

// استرجاع المناطق
router.get('/public-areas', async (req, res) => {
  try {
    const query = 'SELECT * FROM areas';
    const [rows] = await db.query(query);
    res.json(rows);
  } catch (error) {
    res.status(500).json({ message: 'حدث خطأ أثناء جلب المناطق.' });
  }
});

// استرجاع الفروع الأولى
router.get('/public-subcategories', async (req, res) => {
  const { categoryId } = req.query;
  try {
    const query = 'SELECT * FROM alfro WHERE alaqsam_id = ?';
    const [rows] = await db.query(query, [categoryId]);
    res.json(rows);
  } catch (error) {
    res.status(500).json({ message: 'حدث خطأ أثناء جلب الفروع الأولى.' });
  }
});

// استرجاع الفروع الثانية
router.get('/public-subsubcategories', async (req, res) => {
  const { subcategoryId } = req.query;
  try {
    const query = 'SELECT * FROM alfroo WHERE alfro_id = ?';
    const [rows] = await db.query(query, [subcategoryId]);
    res.json(rows);
  } catch (error) {
    res.status(500).json({ message: 'حدث خطأ أثناء جلب الفروع الثانية.' });
  }
});

export default router;
