import express from 'express';
import multer from 'multer';
import bcrypt from 'bcrypt';
import db from './db.js';
import path from 'path';
import fs from 'fs'; // إضافة استيراد وحدة fs
import { v4 as uuidv4 } from 'uuid';

const router = express.Router();

// إعداد التخزين للصور
const storage = multer.diskStorage({
  destination: (req, file, cb) => {
    cb(null, 'uploadsadmin/');
  },
  filename: (req, file, cb) => {
    const ext = path.extname(file.originalname);
    cb(null, `${Date.now()}-${uuidv4()}${ext}`);
  },
});

const upload = multer({ storage });

router.post('/register', upload.single('image'), async (req, res) => {
  const { username, email, password, phone } = req.body;
  let image = req.file ? req.file.filename : null;

  try {

    // التحقق من وجود اسم المستخدم أو البريد الإلكتروني
    const checkQuery = `
      SELECT COUNT(*) AS count 
      FROM admins 
      WHERE username = ? OR email = ?
    `;
    const [rows] = await db.query(checkQuery, [username, email]);

    if (rows[0].count > 0) {
      if (req.file) {
        // حذف الصورة إذا كان اسم المستخدم أو البريد مسجلاً مسبقًا
        fs.unlinkSync(path.join('uploadsadmin', image));
      }
      return res.status(400).json({ message: 'اسم المستخدم أو البريد الإلكتروني مسجل بالفعل' });
    }

    // تشفير كلمة المرور
    const hashedPassword = await bcrypt.hash(password, 10);

    // إدخال البيانات في قاعدة البيانات
    const insertQuery = `
      INSERT INTO admins (username, email, password, phone, image, role, is_visible_a) 
      VALUES (?, ?, ?, ?, ?, ?, ?)
    `;
    await db.query(insertQuery, [
      username,
      email,
      hashedPassword,
      phone,
      image,
      'user',
      1,
    ]);

    res.status(201).json({ message: 'تم تسجيل المستخدم بنجاح' });
  } catch (error) {
    if (!res.headersSent) {
      res.status(500).json({ message: 'حدث خطأ في الخادم' });
    }
  }
});

export default router;
