import express from 'express';
import multer from 'multer';
import fs from 'fs';
import path from 'path';
import { v4 as uuidv4 } from 'uuid'; // مكتبة لتوليد معرفات فريدة ${uuidv4()}${ext}
import db from './db.js'

const router = express.Router();

router.get('/:adId', async (req, res) => {
    const { adId } = req.params;
    try {
      const query = `
        SELECT 
          ads.*, 
          areas.area AS area, 
          cities.city AS city 
        FROM ads
        LEFT JOIN areas ON ads.areasid = areas.id
        LEFT JOIN cities ON ads.citiesid = cities.id
        WHERE ads.id = ?
      `;
      const [rows] = await db.query(query, [adId]);
      if (rows.length === 0) {
        return res.status(404).json({ message: 'الإعلان غير موجود' });
      }
      res.json(rows[0]);
    } catch (error) {
      res.status(500).json({ message: 'حدث خطأ أثناء جلب تفاصيل الإعلان.' });
    }
  });
  
  
  // إعداد التخزين للصور
  const storage = multer.diskStorage({
    destination: (req, file, cb) => {
      cb(null, 'uploadsads/');
    },
    filename: (req, file, cb) => {
      const ext = path.extname(file.originalname);
      cb(null, `${Date.now()}-${uuidv4()}${ext}`);
    },
  });
  
  const upload = multer({ storage });

  
  // تعديل إعلان
  router.put('/edit/:id', async (req, res) => {
    const { id } = req.params;
    const {
      adresads, textads, phoneadsid, useradsid, dateend, alaqsamid, alfroid, alfrooid, modelid, cash, areasid, citiesid, is_visible,
    } = req.body;
  
    try {
      const query = `
        UPDATE ads
        SET adresads = ?, textads = ?, phoneadsid = ?, useradsid = ?, dateend = ?, alaqsamid = ?, alfroid = ?, alfrooid = ?, modelid = ?, cash = ?, areasid = ?, citiesid = ?, is_visible = ?
        WHERE id = ?
      `;
      await db.query(query, [adresads, textads, phoneadsid, useradsid, dateend, alaqsamid, alfroid, alfrooid, modelid, cash, areasid, citiesid, is_visible, id]);
      res.json({ message: 'تم تعديل الإعلان بنجاح!' });
    } catch (error) {
      res.status(500).json({ message: 'حدث خطأ أثناء تعديل الإعلان.' });
    }
  });
  
  export default router;