import express from 'express';
import bcrypt from 'bcrypt';
import multer from 'multer';
import fs from 'fs';
import path from 'path';
import verifyToken from './verifyToken.js';
import { fileURLToPath } from 'url';
import { v4 as uuidv4 } from 'uuid'; // مكتبة لتوليد معرفات فريدة ${uuidv4()}${ext}
import db from './db.js'


const router = express.Router();


const __filename = fileURLToPath(import.meta.url);
const __dirname = path.dirname(__filename);


// إعداد التخزين للصور
const storage = multer.diskStorage({
  destination: (req, file, cb) => {
    cb(null, 'uploadsadmin/');
  },
  filename: (req, file, cb) => {
        const ext = path.extname(file.originalname);
        cb(null, `${Date.now()}-${uuidv4()}${ext}`);
  },
});
const upload = multer({ storage });

// جلب بيانات المستخدم بناءً على التوكن
router.get('/me', verifyToken, async (req, res) => {
  try {
    const [rows] = await db.execute(
      'SELECT username, email, phone, image, role, registration_date FROM admins WHERE id = ?',
      [req.user.id]
    );

    if (rows.length === 0) {
      return res.status(404).json({ message: 'User not found' });
    }

    res.json(rows[0]);
  } catch (error) {
    res.status(500).json({ message: 'Internal server error' });
  }
});

// حذف حساب المستخدم UserMe.jsx
router.delete('/delete', verifyToken, async (req, res) => {
  const userId = req.user.id;

  try {
    // جلب صورة المستخدم
    const [rows] = await db.execute('SELECT image FROM admins WHERE id = ?', [userId]);
    const userImage = rows[0]?.image;

    // حذف المستخدم
    await db.execute('DELETE FROM admins WHERE id = ?', [userId]);

    // حذف الصورة إذا وجدت
    if (userImage) {
      const imagePath = path.join('uploadsadmin', userImage);
      if (fs.existsSync(imagePath)) {
        fs.unlinkSync(imagePath);
      }
    }

    res.json({ message: 'تم حذف الحساب بنجاح' });
  } catch (error) {
    res.status(500).json({ message: 'حدث خطأ أثناء حذف الحساب.' });
  }
});

export default router;
