import express from 'express';
import multer from 'multer';
import path from 'path';
import addWatermark from './uploadWithWatermark.js';
import { v4 as uuidv4 } from 'uuid'; // مكتبة لتوليد معرفات فريدة ${uuidv4()}${ext}

const router = express.Router();

// إعداد التخزين
const storage = multer.diskStorage({
  destination: (req, file, cb) => {
    cb(null, 'uploadsads/'); // مجلد رفع الصور
  },
  filename: (req, file, cb) => {
    const ext = path.extname(file.originalname);
    cb(null, `${Date.now()}-${uuidv4()}${ext}`);
  },
});

const upload = multer({ storage });

router.post('/upload', upload.single('image'), async (req, res) => {
  try {
    const filePath = req.file.path;
    const outputDir = 'uploadsads/';
    const watermarkText = 'ADS2030';

    // إضافة العلامة المائية
    const finalFilePath = await addWatermark(filePath, outputDir, watermarkText);

    // تخزين اسم الملف في قاعدة البيانات (مثال)
    const ad = new AdModel({
      title: req.body.title,
      image: `/uploadsads/${path.basename(finalFilePath)}`,
    });
    await ad.save();

    res.json({ message: 'Image uploaded and saved with watermark!', file: ad.image });
  } catch (error) {
    res.status(500).json({ message: 'Error processing image' });
  }
});


export default router;
