import React, { useEffect, useState } from "react";
import { Link, useParams } from "react-router-dom";
import axios from "axios";
import "./HomeTag.css";

const HomeTag = () => {
  const { id } = useParams(); // جلب معرف الإعلان من الرابط
  const [adDetails, setAdDetails] = useState(null);
  const [loading, setLoading] = useState(true);

  // جلب تفاصيل الإعلان بناءً على المعرف
  useEffect(() => {

       let isFetching = false; 

    const fetchAdDetails = async () => {


        if (isFetching) return; // منع التكرار
        isFetching = true;
        
      try {
        const response = await axios.get(`http://localhost:3001/api/ads/${id}`);
        setAdDetails(response.data);
      } catch (error) {

      } finally {
        setLoading(false);
      }
    };
    fetchAdDetails();
  }, [id]);

  // عرض رسالة أثناء تحميل البيانات
  if (loading) {
    return <p>جاري تحميل التفاصيل...</p>;
  }

  // عرض رسالة إذا لم يتم العثور على الإعلان
  if (!adDetails) {
    return <p>عذرًا، لم يتم العثور على الإعلان.</p>;
  }

  return (
    <div className="home-tag-page">
      {/* الهيدر الأول */}
      <header className="header header1">
  {/* اللوجو على اليسار */}
  <img src="/logo/001.png" alt="Logo" className="logo-image" />
  
  {/* عنوان الموقع على اليمين */}
  <span className="site-name">إعلانات 2030</span>
</header>




      {/* الهيدر الثاني */}
<header className="header header2">
  <div className="button-container">
    <button className="button">
      <Link to="/">الرئيسية</Link>
    </button>               
    <button className="button">
      <Link to="/login">تسجيل الدخول</Link>
    </button>
    <button className="button">
      <Link to="/register">تسجيل جديد</Link>
    </button>
  </div>
</header>

      {/* تفاصيل الإعلان */}
      <div className="ad-details-container">
        {/* عرض عنوان الإعلان */}
        {adDetails.adresads && <h1 className="ad-title">{adDetails.adresads}</h1>}

        {/* عرض وصف الإعلان */}
        {adDetails.textads && <p className="ad-description">{adDetails.textads}</p>}

        {/* عرض معلومات الإعلان */}
        <div className="ad-info">
          {adDetails.area && <p>{adDetails.area}</p>}
          {adDetails.city && <p>{adDetails.city}</p>}
          {adDetails.phoneadsid && <p>للتواصل: {adDetails.phoneadsid}</p>}
          {adDetails.useradsid && <p>المعلن: {adDetails.useradsid}</p>}
          {adDetails.cash && <p>السعر: {`${adDetails.cash} ريال`}</p>}
          {adDetails.datestart && (
            <p>
              تاريخ الإعلان:{" "}
              {new Date(adDetails.datestart)
                .toLocaleDateString("en-GB")
                .replace(/\//g, "-")}
            </p>
          )}
          {adDetails.dateend && (
            <p>
              الإنتهاء:{" "}
              {new Date(adDetails.dateend)
                .toLocaleDateString("en-GB")
                .replace(/\//g, "-")}
            </p>
          )}
          {adDetails.id && <p>#{adDetails.id}</p>}
          {/* عرض الصور */}
          {adDetails.img1 && (
            <img
              src={`http://localhost:3001/uploadsads/${adDetails.img1}`}
              alt="Ad Image 1"
              className="ad-image"
            />
          )}
          {adDetails.img2 && (
            <img
              src={`http://localhost:3001/uploadsads/${adDetails.img2}`}
              alt="Ad Image 2"
              className="ad-image"
            />
          )}
          {adDetails.img3 && (
            <img
              src={`http://localhost:3001/uploadsads/${adDetails.img3}`}
              alt="Ad Image 3"
              className="ad-image"
            />
          )}
        </div>
      </div>
    </div>
  );
};

export default HomeTag;
