import React, { useEffect, useState } from 'react';
import { useNavigate } from 'react-router-dom';
import { getAuthDetails,/* logout */ } from '../authService';
import axios from 'axios'
import './Fr2.css'

function Fr2() {

  const navigate = useNavigate();
  const [userRole, setUserRole] = useState(null);
  // الكوكيز والتوكن
  useEffect(() => {
    const checkAuth = async () => {
      try {
        const authDetails = await getAuthDetails();
        if (authDetails.role !== 'admin') {
            alert("الصفحة المطلوبة غير متوفرة")
          navigate('/login'); // إعادة التوجيه إذا لم يكن المستخدم Admin
        } else {
          setUserRole(authDetails.role); // تعيين الدور
        }
      } catch (error) {
        navigate('/login'); // إعادة التوجيه عند حدوث خطأ
      }
    };
    checkAuth();
  }, [navigate]);

/*
  // تسجيل الخروج
  const handleLogout = async () => {
    try {
      await logout();
      navigate('/login');
    } catch (error) {

    }
  };
*/

  // الفرع الثاني
  const [branchesSecond, setBranchesSecond] = useState([]);
  const [branchesFirst, setBranchesFirst] = useState([]);
  const [newBranch, setNewBranch] = useState('');
  const [selectedBranchFirst, setSelectedBranchFirst] = useState('');
  const [editId, setEditId] = useState(null);
  const [editBranch, setEditBranch] = useState('');
  const [editBranchFirst, setEditBranchFirst] = useState('');

  // جلب الفروع الأولى والثانية عند تحميل الصفحة
  useEffect(() => {
    fetchBranchesFirst();
    fetchBranchesSecond();
  }, []);

  const fetchBranchesFirst = async () => {
    try {
      const response = await axios.get('http://localhost:3001/api/alfro');
      setBranchesFirst(response.data);
    } catch (error) {

    }
  };

  const fetchBranchesSecond = async () => {
    try {
      const response = await axios.get('http://localhost:3001/api/alfroo');
      setBranchesSecond(response.data);
    } catch (error) {

    }
  };

  const addBranchSecond = async (e) => {
    e.preventDefault();

    try {
      const response = await axios.post('http://localhost:3001/api/alfroo/add', {
        alfr2: newBranch,
        alfro_id: selectedBranchFirst,
      });
      setBranchesSecond([
        ...branchesSecond,
        { id: response.data.id, alfr2: newBranch, alfro_id: selectedBranchFirst, alfr1: branchesFirst.find(b => b.id === +selectedBranchFirst)?.alfr1 },
      ]);
      setNewBranch('');
      setSelectedBranchFirst('');
    } catch (error) {

    }
  };

  const deleteBranchSecond = async (id) => {
    try {
      await axios.delete(`http://localhost:3001/api/alfroo/delete/${id}`);
      setBranchesSecond(branchesSecond.filter((b) => b.id !== id));
    } catch (error) {

    }
  };

  const startEdit = (id, alfr2, alfro_id) => {
    setEditId(id);
    setEditBranch(alfr2);
    setEditBranchFirst(alfro_id);
  };

  const saveEdit = async () => {
    try {
      await axios.put(`http://localhost:3001/api/alfroo/edit/${editId}`, {
        alfr2: editBranch,
        alfro_id: editBranchFirst,
      });
      setBranchesSecond(
        branchesSecond.map((b) =>
          b.id === editId ? { ...b, alfr2: editBranch, alfro_id: editBranchFirst, alfr1: branchesFirst.find(bf => bf.id === +editBranchFirst)?.alfr1 } : b
        )
      );
      setEditId(null);
      setEditBranch('');
      setEditBranchFirst('');
    } catch (error) {

    }
  };

  const cancelEdit = () => {
    setEditId(null);
    setEditBranch('');
    setEditBranchFirst('');
  };

  return (
    <div className="fr2-container">

{userRole && <>
       <h1>أضف فرع ثاني</h1>

             {/* فورم إضافة فرع جديد */}
      <form onSubmit={addBranchSecond}>
        <input
          type="text"
          value={newBranch}
          onChange={(e) => setNewBranch(e.target.value)}
          placeholder="اسم الفرع الثاني"
          required
        />
        <select value={selectedBranchFirst} onChange={(e) => setSelectedBranchFirst(e.target.value)} required>
          <option value="">اختر الفرع الأول</option>
          {branchesFirst.map((branch) => (
            <option key={branch.id} value={branch.id}>
              {branch.alfr1}
            </option>
          ))}
        </select>
        <button type="submit">إضافة فرع ثاني</button>
      </form>

      {/* قائمة الفروع الثانية */}
      <ul>
        {branchesSecond.map((branch) => (
          <li key={branch.id}>
            {editId === branch.id ? (
              <>
                <input
                  type="text"
                  value={editBranch}
                  onChange={(e) => setEditBranch(e.target.value)}
                />
                <select value={editBranchFirst} onChange={(e) => setEditBranchFirst(e.target.value)}>
                  {branchesFirst.map((branchFirst) => (
                    <option key={branchFirst.id} value={branchFirst.id}>
                      {branchFirst.alfr1}
                    </option>
                  ))}
                </select>
                <button onClick={saveEdit}>حفظ</button>
                <button onClick={cancelEdit}>تراجع</button>
              </>
            ) : (
              <>
                {branch.alfr2} (الفرع الأول: {branch.alfr1})
                <button onClick={() => startEdit(branch.id, branch.alfr2, branch.alfro_id)}>تعديل</button>
                <button onClick={() => deleteBranchSecond(branch.id)}>حذف</button>
              </>
            )}
          </li>
        ))}
      </ul>

      </>}
        
    </div>
  )
}

export default Fr2