import React, { useEffect, useState } from 'react';
import { useNavigate } from 'react-router-dom';
import { getAuthDetails,/* logout */ } from '../authService';
import axios from 'axios'
import './Modl.css';

function Modl() {

  const navigate = useNavigate();
  const [userRole, setUserRole] = useState(null);
  // الكوكيز والتوكن
  useEffect(() => {
    const checkAuth = async () => {
      try {
        const authDetails = await getAuthDetails();
        if (authDetails.role !== 'admin') {
            alert("الصفحة المطلوبة غير متوفرة")
          navigate('/login'); // إعادة التوجيه إذا لم يكن المستخدم Admin
        } else {
          setUserRole(authDetails.role); // تعيين الدور
        }
      } catch (error) {

        navigate('/login'); // إعادة التوجيه عند حدوث خطأ
      }
    };
    checkAuth();
  }, [navigate]);

/*
  // تسجيل الخروج
  const handleLogout = async () => {
    try {
      await logout();
      navigate('/login');
    } catch (error) {

    }
  };
*/

  // الموديل
  const [models, setModels] = useState([]);
  const [newModel, setNewModel] = useState('');
  const [editId, setEditId] = useState(null);
  const [editModel, setEditModel] = useState('');

  // جلب الموديلات عند تحميل الصفحة
  useEffect(() => {
    fetchModels();
  }, []);

  const fetchModels = async () => {
    try {
      const response = await axios.get('http://localhost:3001/api/modl');
      setModels(response.data);
    } catch (error) {

    }
  };

  const addModel = async (e) => {
    e.preventDefault();

    try {
      const response = await axios.post('http://localhost:3001/api/modl/add', { mdl: newModel });
      setModels([...models, { id: response.data.id, mdl: newModel }]);
      setNewModel('');
    } catch (error) {

    }
  };

  const deleteModel = async (id) => {
    try {
      await axios.delete(`http://localhost:3001/api/modl/delete/${id}`);
      setModels(models.filter((m) => m.id !== id));
    } catch (error) {

    }
  };

  const startEdit = (id, mdl) => {
    setEditId(id);
    setEditModel(mdl);
  };

  const saveEdit = async () => {
    try {
      await axios.put(`http://localhost:3001/api/modl/edit/${editId}`, { mdl: editModel });
      setModels(models.map((m) => (m.id === editId ? { ...m, mdl: editModel } : m)));
      setEditId(null);
      setEditModel('');
    } catch (error) {

    }
  };

  const cancelEdit = () => {
    setEditId(null);
    setEditModel('');
  };

  return (
    <div className="modl-container">

{userRole && <>
       <h1>أضف موديل جديد</h1>

             {/* فورم إضافة موديل جديد */}
      <form onSubmit={addModel}>
        <input
          type="text"
          value={newModel}
          onChange={(e) => setNewModel(e.target.value)}
          placeholder="اسم موديل السنة"
          required
        />
        <button type="submit">إضافة موديل</button>
      </form>

      {/* قائمة الموديلات */}
      <ul>
        {models.map((model) => (
          <li key={model.id}>
            {editId === model.id ? (
              <>
                <input className='modl'
                  type="text"
                  value={editModel}
                  onChange={(e) => setEditModel(e.target.value)}
                />
                <button className='saveeditm' onClick={saveEdit}>حفظ</button>
                <button className='canceleditm' onClick={cancelEdit}>تراجع</button>
              </>
            ) : (
              <>
                {model.mdl}
                <button onClick={() => startEdit(model.id, model.mdl)}>تعديل</button>
                <button onClick={() => deleteModel(model.id)}>حذف</button>
              </>
            )}
          </li>
        ))}
      </ul>

      </>}
        
    </div>
  )
}

export default Modl