import React, { useEffect, useState } from 'react';
import {useNavigate } from 'react-router-dom';
import { getAuthDetails,/* logout */} from '../authService';
import axios from 'axios';
import './UserAds.css'

const UserAds = ({ onAdAdded }) => {
  const navigate = useNavigate();
  const [userRole, setUserRole] = useState(null);
  
  // التحقق من التوكن والكوكيز
  useEffect(() => {
    const checkAuth = async () => {
      try {
        const authDetails = await getAuthDetails();
        if (authDetails.role !== 'user') {
          alert("الصفحة المطلوبة غير متوفرة")
          navigate('/login'); // إعادة التوجيه إذا لم يكن المستخدم User
        } else {
          setUserRole(authDetails.role); // تعيين الدور
        }
      } catch (error) {
        navigate('/login'); // إعادة التوجيه عند حدوث خطأ
      }
    };
    checkAuth();
  }, [navigate]);

/*
  // تسجيل خروج
  const handleLogout = async () => {
    try {
      await logout();
      navigate('/login');
    } catch (error) {
    }
  };
*/

  // الإعلانات
  const [userDetails, setUserDetails] = useState(null);
  const [formData, setFormData] = useState({
    adresads: '',
    textads: '',
    phoneadsid: '',
    useradsid: '',
    dateend: '',
    alaqsamid: '',
    alfroid: '',
    alfrooid: '',
    modelid: '',
    cash: '',
    areasid: '',
    citiesid: '',
    is_visible: 1,
  });
  const [files, setFiles] = useState({ img1: null, img2: null, img3: null });
  const [foreignData, setForeignData] = useState({
    alaqsam: [],
    alfro: [],
    alfroo: [],
    model: [],
    areas: [],
    cities: [],
  });
  const [filteredCities, setFilteredCities] = useState([]);
  const [filteredAlfro, setFilteredAlfro] = useState([]);
  const [filteredAlfroo, setFilteredAlfroo] = useState([]);

  // جلب بيانات المستخدم عند تسجيل الدخول
  useEffect(() => {
    const fetchUserDetails = async () => {
      try {
        const authDetails = await getAuthDetails();
        const response = await axios.get('http://localhost:3001/api/userme/me', { withCredentials: true });
        setUserDetails(response.data);
        setFormData((prev) => ({
          ...prev,
          phoneadsid: response.data.phone,
          useradsid: response.data.username,
        }));
      } catch (error) {
        alert('Unauthorized: Please login again.');
        navigate('/login');
      }
    };

    fetchUserDetails();
  }, [navigate]);

  // جلب البيانات الخارجية (الأقسام والفروع والمناطق)
  useEffect(() => {
    const fetchForeignData = async () => {
      try {
        const [alaqsam, alfro, alfroo, model, areas, cities] = await Promise.all([
          axios.get('http://localhost:3001/api/alaqsam'),
          axios.get('http://localhost:3001/api/alfro'),
          axios.get('http://localhost:3001/api/alfroo'),
          axios.get('http://localhost:3001/api/modl'),
          axios.get('http://localhost:3001/api/areas'),
          axios.get('http://localhost:3001/api/cities'),
        ]);

        setForeignData({
          alaqsam: alaqsam.data,
          alfro: alfro.data,
          alfroo: alfroo.data,
          model: model.data,
          areas: areas.data,
          cities: cities.data,
          admins: cities.data,
        });
      } catch (error) {

      }
    };

    fetchForeignData();
  }, []);

  // تحديث الحقول المترابطة بناءً على الإدخال
  const handleInputChange = (e) => {
    const { name, value } = e.target;

    setFormData((prev) => ({
      ...prev,
      [name]: value,
    }));

    if (name === 'alaqsamid') {
      const relatedAlfro = foreignData.alfro.filter((item) => item.alaqsam_id === parseInt(value));
      setFilteredAlfro(relatedAlfro);
      setFormData((prev) => ({ ...prev, alfroid: '', alfrooid: '' }));
      setFilteredAlfroo([]);
    }

    if (name === 'alfroid') {
      const relatedAlfroo = foreignData.alfroo.filter((item) => item.alfro_id === parseInt(value));
      setFilteredAlfroo(relatedAlfroo);
      setFormData((prev) => ({ ...prev, alfrooid: '' }));
    }

    if (name === 'areasid') {
      const relatedCities = foreignData.cities.filter((city) => city.areas_id === parseInt(value));
      setFilteredCities(relatedCities);
      setFormData((prev) => ({ ...prev, citiesid: '' }));
    }

    if (name === 'dateend') {
      const currentDate = new Date();
      const monthsToAdd = parseInt(value, 10);
      if (!isNaN(monthsToAdd)) {
        const calculatedDate = new Date(
          currentDate.getFullYear(),
          currentDate.getMonth() + monthsToAdd,
          currentDate.getDate()
        );
        setFormData((prev) => ({
          ...prev,
          dateend: calculatedDate.toISOString().split('T')[0],
        }));
      }
    }
  };

  const handleFileChange = (e) => {
    const { name, files } = e.target;
  
    if (files.length > 0) {
      const file = files[0];
      const allowedTypes = ['image/jpeg', 'image/png', 'image/jpg', 'image/webp'];
  
      // التحقق من نوع الملف
      if (!allowedTypes.includes(file.type)) {
        alert('يُسمح فقط برفع الصور بصيغ JPEG, PNG, JPG, WEBP.');
        return;
      }
  
      // التحقق من حجم الملف (اختياري - مثال: أقل من 2 ميجابايت)
      const maxSize = 2 * 1024 * 1024; // 2MB
      if (file.size > maxSize) {
        alert('حجم الصورة يجب أن يكون أقل من 2 ميجابايت.');
        return;
      }
  
      // إذا كان الملف صحيحًا، تحديث الحالة
      setFiles((prev) => ({ ...prev, [name]: file }));
    }
  };
  
  
  // إرسال الإعلان إلى قاعدة البيانات
  const handleSubmit = async (e) => {
    e.preventDefault();

    if (!files.img1) {
      alert('الصورة الأولى مطلوبة!');
      return;
    }

    const data = new FormData();
    for (const key in formData) {
      data.append(key, formData[key] || null);
    }
    for (const key in files) {
      if (files[key]) {
        data.append(key, files[key]);
      }
    }

    try {
      await axios.post('http://localhost:3001/api/userads/add', data, {
        headers: { 'Content-Type': 'multipart/form-data' },
      });
      alert('تمت إضافة الإعلان بنجاح!');
     // navigate('/userindex'); // إعادة توجيه إلى قائمة الإعلانات
     onAdAdded(); // الانتقال إلى صفحة "عرض الإعلانات"
    } catch (error) {

    }
  };

  return (
    <div  className="user-container">
        
          {userRole && <>
           <h1>أضف إعلان جديد</h1> 
<div className="form-container">
          <form onSubmit={handleSubmit} style={{ marginBottom: '20px' }}>
            <div>
              <input
                type="text"
                name="adresads"
                value={formData.adresads}
                onChange={handleInputChange}
                placeholder="عنوان الإعلان"
                required
              />
            </div>
            <div>
              <textarea
                name="textads"
                value={formData.textads}
                onChange={handleInputChange}
                placeholder="وصف الإعلان"
                required
              />
            </div>
            <div>
              <select name="alaqsamid" value={formData.alaqsamid} onChange={handleInputChange}>
                <option value="">اختر القسم</option>
                {foreignData.alaqsam.map((item) => (
                  <option key={item.id} value={item.id}>
                    {item.qsm}
                  </option>
                ))}
              </select>
            </div>
            {filteredAlfro.length > 0 && (
              <div>
                <select name="alfroid" value={formData.alfroid} onChange={handleInputChange}>
                  <option value="">اختر الفرع الأول</option>
                  {filteredAlfro.map((item) => (
                    <option key={item.id} value={item.id}>
                      {item.alfr1}
                    </option>
                  ))}
                </select>
              </div>
            )}
            {filteredAlfroo.length > 0 && (
              <div>
                <select name="alfrooid" value={formData.alfrooid} onChange={handleInputChange}>
                  <option value="">اختر الفرع الثاني</option>
                  {filteredAlfroo.map((item) => (
                    <option key={item.id} value={item.id}>
                      {item.alfr2}
                    </option>
                  ))}
                </select>
              </div>
            )}

            {formData.alaqsamid === '16' && (
              <div>
                <select name="modelid" value={formData.modelid} onChange={handleInputChange}>
                  <option value="">اختر الموديل</option>
                  {foreignData.model.map((model) => (
                    <option key={model.id} value={model.mdl}>
                      {model.mdl}
                    </option>
                  ))}
                </select>
              </div>
            )}

            <div>
              <select name="areasid" value={formData.areasid} onChange={handleInputChange}>
                <option value="">اختر المنطقة</option>
                {foreignData.areas.map((area) => (
                  <option key={area.id} value={area.id}>
                    {area.area}
                  </option>
                ))}
              </select>
            </div>
            {filteredCities.length > 0 && (
              <div>
                <select name="citiesid" value={formData.citiesid} onChange={handleInputChange}>
                  <option value="">اختر المدينة</option>
                  {filteredCities.map((city) => (
                    <option key={city.id} value={city.id}>
                      {city.city}
                    </option>
                  ))}
                </select>
              </div>
            )}

            <div>
            <select name="dateend" onChange={handleInputChange} required>
          <option value="">اختر مدة الانتهاء</option>
          <option value="1">شهر</option>
          <option value="2">شهران</option>
          <option value="3">ثلاثة أشهر</option>
          <option value="6">ستة أشهر</option>
          <option value="12">سنة</option>
        </select>
            </div>
            <div>
              <input type="number" name="cash" value={formData.cash} onChange={handleInputChange} placeholder="السعر" />
            </div>
            <div>
              <input type="file" name="img1" onChange={handleFileChange} required />
            </div>
            <div>
              <input type="file" name="img2" onChange={handleFileChange} />
            </div>
            <div>
              <input type="file" name="img3" onChange={handleFileChange} />
            </div>
            <div>
              <button type="submit">إضافة إعلان</button>
            </div>
          </form>  
</div>


          </>}

    </div>
  )
}

export default UserAds